################
Looping functions
################

Functions for iterating over parameter spaces in VCA and CDMFT calculations.
These include loops with predictors, the Hartree procedure, and fading between
parameter sets.

.. automodule:: pyqcm._loop
    :members:
    :undoc-members:
    :exclude-members: first_time